/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.pdfbota.bota;


import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.viewpager2.widget.ViewPager2;

import com.compdfkit.tools.R;
import com.compdfkit.tools.pdfbota.bota.adapter.CBotaViewPagerAdapter;
import com.compdfkit.tools.pdfview.CPDFView;
import com.compdfkit.tools.utils.dialog.DialogFragmentUtil;
import com.compdfkit.tools.utils.view.CToolBar;
import com.google.android.material.bottomsheet.BottomSheetBehavior;
import com.google.android.material.bottomsheet.BottomSheetDialogFragment;
import com.google.android.material.tabs.TabLayout;
import com.google.android.material.tabs.TabLayoutMediator;


/**
 * The interface contains two PDF function lists, the PDF thumbnail list and the PDF outline list.
 * @see com.compdfkit.tools.pdfbota.pdfthumbnail.CPDFThumbnailFragment
 * @see com.compdfkit.tools.pdfbota.pdfoutline.CPDFOutlineFragment
 */
public class CPDFBotaDialogFragment extends BottomSheetDialogFragment {

    private TabLayout tabLayout;

    private CToolBar toolBar;

    private ViewPager2 viewPager2;

    private CPDFView cpdfView;

    public static CPDFBotaDialogFragment newInstance(){
        return new CPDFBotaDialogFragment();
    }

    public void setCPdfReaderView(CPDFView cpdfView){
        this.cpdfView = cpdfView;
    }


    @Override
    public void onStart() {
        super.onStart();
        BottomSheetBehavior<View> behavior = BottomSheetBehavior.from((View) getView().getParent());
        DialogFragmentUtil.setBottomSheetDialogFragmentFullScreen(getDialog(), behavior);
    }

    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.tools_cpdf_bota_dialog_fragment, container, false);
        tabLayout = rootView.findViewById(R.id.tab_layout);
        viewPager2 = rootView.findViewById(R.id.view_pager);
        toolBar = rootView.findViewById(R.id.tool_bar);
        toolBar.setBackBtnClickListener(v -> dismiss());
        return rootView;
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        initViewPagers();
    }

    private void initViewPagers(){
        CBotaViewPagerAdapter boTaViewPagerAdapter = new CBotaViewPagerAdapter(getChildFragmentManager(), getLifecycle(), cpdfView);
        //Listen to thumbnail and outline click events, CPDFReaderView jumps to the corresponding page and dismisses the popup
        boTaViewPagerAdapter.setPDFDisplayPageIndexListener(pageIndex -> {
            if (cpdfView != null) {
                cpdfView.getCPdfReaderView().setDisplayPageIndex(pageIndex);
            }
            dismiss();
        });
        viewPager2.setAdapter(boTaViewPagerAdapter);
        viewPager2.registerOnPageChangeCallback(new ViewPager2.OnPageChangeCallback() {
            @Override
            public void onPageSelected(int position) {
                toolBar.setTitle(boTaViewPagerAdapter.titles[position]);
            }
        });
        TabLayoutMediator tabLayoutMediator = new TabLayoutMediator(tabLayout, viewPager2, (tab, position) -> {
            tab.setText(boTaViewPagerAdapter.titles[position]);
        });
        tabLayoutMediator.attach();
    }


    
}
