/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.pdfbota.bota.adapter;


import androidx.annotation.NonNull;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentManager;
import androidx.lifecycle.Lifecycle;
import androidx.viewpager2.adapter.FragmentStateAdapter;

import com.compdfkit.tools.R;
import com.compdfkit.tools.interfaces.OnSetPDFDisplayPageIndexListener;
import com.compdfkit.tools.pdfbota.pdfoutline.CPDFOutlineFragment;
import com.compdfkit.tools.pdfbota.pdfthumbnail.CPDFThumbnailFragment;
import com.compdfkit.tools.pdfview.CPDFView;


/**
 * The adapter contains two fragments, namely the thumbnail list fragment and the PDF outline list fragment.
 * @see CPDFThumbnailFragment
 * @see CPDFOutlineFragment
 */
public class CBotaViewPagerAdapter extends FragmentStateAdapter {
    /**
     * Array of titles for the two fragments
     */
    public int[] titles = new int[]{R.string.tools_thumbnail, R.string.tools_outline};

    /**
     * The PDF reader view object
     */
    private CPDFView cpdfView;

    /**
     * Listener for setting the display page index of the PDF
     */
    private OnSetPDFDisplayPageIndexListener pdfDisplayPageIndexListener;

    public CBotaViewPagerAdapter(@NonNull FragmentManager fragmentManager, @NonNull Lifecycle lifecycle, CPDFView cpdfView) {
        super(fragmentManager, lifecycle);
        this.cpdfView = cpdfView;
    }


    @NonNull
    @Override
    public Fragment createFragment(int position) {
        if (position == 0){
            return thumbnailFragment();
        }else {
            return outlineFragment();
        }
    }

    @Override
    public int getItemCount() {
        return titles.length;
    }

    /**
     * Method that creates and returns a new outline fragment
     * @return CPDFOutlineFragment
     */
    private CPDFOutlineFragment outlineFragment(){
        CPDFOutlineFragment fragment = CPDFOutlineFragment.newInstance();
        fragment.setOutlineClickListener(pdfDisplayPageIndexListener);
        fragment.setCPdfReaderView(cpdfView);
        return fragment;
    }

    /**
     * Method that creates and returns a new thumbnail fragment
     * @return CPDFThumbnailFragment
     */
    private CPDFThumbnailFragment thumbnailFragment(){
        CPDFThumbnailFragment fragment = CPDFThumbnailFragment.newInstance();
        fragment.setPDFDisplayPageIndexListener(pdfDisplayPageIndexListener);
        fragment.setCPdfReaderView(cpdfView);
        return fragment;
    }

    /**
     * Method that sets the PDF display page index listener
     * @param displayPageIndexListener
     */
    public void setPDFDisplayPageIndexListener(OnSetPDFDisplayPageIndexListener displayPageIndexListener){
        this.pdfDisplayPageIndexListener = displayPageIndexListener;
    }
}
