/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.pdfbota.pdfoutline;


import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.compdfkit.tools.R;
import com.compdfkit.tools.interfaces.OnSetPDFDisplayPageIndexListener;
import com.compdfkit.tools.pdfbota.pdfoutline.adapter.COutlineListAdapter;
import com.compdfkit.tools.pdfbota.pdfoutline.bean.COutlineData;
import com.compdfkit.tools.pdfbota.pdfoutline.data.COutlineDatas;
import com.compdfkit.tools.pdfview.CPDFView;

import java.util.ArrayList;

public class CPDFOutlineFragment extends Fragment {

    /**
     * Outline maximum expansion level
     */
    public static final int OUTLINE_MAX_LEVEL = 10;

    private RecyclerView rvOutlineRecyclerView;

    private OnSetPDFDisplayPageIndexListener outlineCallback;

    private CPDFView cpdfView;

    COutlineListAdapter outlineListAdapter = null;

    /**
     * Creates a new instance of CPDFOutlineFragment.
     *
     * @return A new instance of CPDFOutlineFragment.
     */
    public static CPDFOutlineFragment newInstance() {
        return new CPDFOutlineFragment();
    }

    /**
     * Sets the CPDFReaderView instance for this fragment.
     *
     * @param cPdfView The CPDFReaderView instance.
     */
    public void setCPdfReaderView(CPDFView cPdfView) {
        this.cpdfView = cPdfView;
    }

    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        // Inflate the layout for this fragment.
        View rootView = inflater.inflate(R.layout.tools_cpdf_outline_list_fragment, container, false);
        rvOutlineRecyclerView = rootView.findViewById(R.id.rv_outline);
        return rootView;
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        // Set up the adapter and the RecyclerView.
        outlineListAdapter = new COutlineListAdapter();
        outlineListAdapter.setOutlineClickListener(outlineCallback);
        rvOutlineRecyclerView.setLayoutManager(new LinearLayoutManager(getContext()));
        rvOutlineRecyclerView.setAdapter(outlineListAdapter);
        // Set the list of outline data for the adapter to display.
        outlineListAdapter.setList(getOutlineData());
    }

    /**
     * Returns the list of outline data for the PDF document.
     *
     * @return The list of outline data.
     */
    private ArrayList<COutlineData> getOutlineData() {
        if (cpdfView != null) {
            return COutlineDatas.getOutlineList(cpdfView, OUTLINE_MAX_LEVEL);
        } else {
            return new ArrayList<>();
        }
    }

    /**
     * Sets the listener for outline item click events.
     *
     * @param outlineClickListener The listener to set.
     */
    public void setOutlineClickListener(OnSetPDFDisplayPageIndexListener outlineClickListener) {
        this.outlineCallback = outlineClickListener;
    }


}
