package com.compdfkit.tools.pdfinfo;

import android.os.Bundle;
import android.os.ParcelFileDescriptor;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.widget.AppCompatTextView;
import androidx.fragment.app.FragmentManager;

import com.compdfkit.core.document.CPDFDocument;
import com.compdfkit.core.document.CPDFDocumentPermissionInfo;
import com.compdfkit.core.document.CPDFInfo;
import com.compdfkit.tools.R;
import com.compdfkit.tools.pdfview.CPDFView;
import com.compdfkit.tools.utils.dialog.DialogFragmentUtil;
import com.compdfkit.tools.utils.view.CToolBar;
import com.google.android.material.bottomsheet.BottomSheetBehavior;
import com.google.android.material.bottomsheet.BottomSheetDialogFragment;


public class CPDFDocumentInfoDialogFragment extends BottomSheetDialogFragment {

    private CToolBar toolBar;
    private AppCompatTextView tvPDFFileName;
    private AppCompatTextView tvPDFSize;
    private AppCompatTextView tvPDFTitle;
    private AppCompatTextView tvPDFAuthor;
    private AppCompatTextView tvPDFSubject;
    private AppCompatTextView tvPDFKeywords;
    private AppCompatTextView tvPDFVersion;
    private AppCompatTextView tvPDFPageNum;
    private AppCompatTextView tvPDFCreator;
    private AppCompatTextView tvPDFCreationDate;
    private AppCompatTextView tvPDFModificationDate;
    private AppCompatTextView tvPDFAllowPrint;
    private AppCompatTextView tvPDFAllowCopy;
    private AppCompatTextView tvPDFAllowDocumentChanges;
    private AppCompatTextView tvPDFAllowDocumentAssembly;
    private AppCompatTextView tvPDFAllowDocumentCommenting;
    private AppCompatTextView tvPDFAllowDocumentFormFieldEntry;


    private CPDFView cpdfView;

    public static void show(FragmentManager fragmentManager, CPDFView cpdfView) {
        CPDFDocumentInfoDialogFragment documentInfoDialogFragment = new CPDFDocumentInfoDialogFragment();
        documentInfoDialogFragment.setCPdfReaderView(cpdfView);
        documentInfoDialogFragment.show(fragmentManager, "documentInfoDialogFragment");
    }

    public void setCPdfReaderView(CPDFView cpdfView) {
        this.cpdfView = cpdfView;
    }


    @Override
    public void onStart() {
        super.onStart();
        BottomSheetBehavior<View> behavior = BottomSheetBehavior.from((View) getView().getParent());
        behavior.setDraggable(false);
        DialogFragmentUtil.setBottomSheetDialogFragmentFullScreen(getDialog(), behavior);
    }


    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.tools_pdf_document_info_dialog_fragment, container, false);
        toolBar = rootView.findViewById(R.id.tool_bar);
        toolBar.setBackBtnClickListener(v -> {
            dismiss();
        });
        tvPDFFileName = rootView.findViewById(R.id.id_pdf_info_fileName);
        tvPDFSize = rootView.findViewById(R.id.id_pdf_info_size);
        tvPDFTitle = rootView.findViewById(R.id.id_pdf_info_title);
        tvPDFAuthor = rootView.findViewById(R.id.id_pdf_info_author);
        tvPDFSubject = rootView.findViewById(R.id.id_pdf_info_subject);
        tvPDFKeywords = rootView.findViewById(R.id.id_pdf_info_keywords);
        tvPDFVersion = rootView.findViewById(R.id.id_pdf_info_version);
        tvPDFPageNum = rootView.findViewById(R.id.id_pdf_info_pages);
        tvPDFCreator = rootView.findViewById(R.id.id_pdf_info_creator);
        tvPDFCreationDate = rootView.findViewById(R.id.id_pdf_info_creationDate);
        tvPDFModificationDate = rootView.findViewById(R.id.id_pdf_info_modification);
        tvPDFAllowPrint = rootView.findViewById(R.id.id_pdf_info_allowPrint);
        tvPDFAllowCopy = rootView.findViewById(R.id.id_pdf_info_allowCopy);
        tvPDFAllowDocumentChanges = rootView.findViewById(R.id.id_pdf_info_document_changes);
        tvPDFAllowDocumentAssembly = rootView.findViewById(R.id.id_pdf_info_document_assembly);
        tvPDFAllowDocumentCommenting = rootView.findViewById(R.id.id_pdf_info_document_commenting);
        tvPDFAllowDocumentFormFieldEntry = rootView.findViewById(R.id.id_pdf_info_document_form_field_entry);
        return rootView;
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);

        if (cpdfView != null) {
            CPDFDocument document = cpdfView.getCPdfReaderView().getPDFDocument();
            CPDFInfo cpdfInfo = document.getInfo();
            CPDFDocumentPermissionInfo permissionInfo = document.getPermissionsInfo();

            tvPDFFileName.setText(document.getFileName());
            tvPDFSize.setText(getDocumentSize(document));
            tvPDFTitle.setText(cpdfInfo.getTitle());
            tvPDFAuthor.setText(cpdfInfo.getAuthor());
            tvPDFSubject.setText(cpdfInfo.getSubject());
            tvPDFKeywords.setText(cpdfInfo.getKeywords());

            tvPDFVersion.setText(String.valueOf(document.getMajorVersion()));
            tvPDFPageNum.setText(String.valueOf(document.getPageCount()));
            tvPDFCreator.setText(cpdfInfo.getCreator());
            tvPDFCreationDate.setText(transformPDFDate(cpdfInfo.getCreationDate()));
            tvPDFModificationDate.setText(transformPDFDate(cpdfInfo.getModificationDate()));

            tvPDFAllowPrint.setText(allowStr(permissionInfo.isAllowsPrinting()));
            tvPDFAllowCopy.setText(allowStr(permissionInfo.isAllowsCopying()));
            tvPDFAllowDocumentChanges.setText(allowStr(permissionInfo.isAllowsDocumentChanges()));
            tvPDFAllowDocumentAssembly.setText(allowStr(permissionInfo.isAllowsDocumentAssembly()));
            tvPDFAllowDocumentCommenting.setText(allowStr(permissionInfo.isAllowsCommenting()));
            tvPDFAllowDocumentFormFieldEntry.setText(allowStr(permissionInfo.isAllowsFormFieldEntry()));

        }


    }

    private String allowStr(boolean allow){
        return getString(allow ? R.string.tools_yes : R.string.tools_no);
    }


    /**
     * Transform a PDF date string in the format D:20230130060237+00'00' to a human-readable yyyy-MM-dd HH:mm:ss date string.
     *
     * @param inputDate the PDF date string to be transformed
     * @return the transformed date string in yyyy-MM-dd HH:mm:ss format, or an empty string if the input string is null or too short
     */
    private String transformPDFDate(String inputDate) {
        if (TextUtils.isEmpty(inputDate) || inputDate.length() < 16) {
            return "";
        }

        String year = inputDate.substring(2, 6);
        String month = inputDate.substring(6, 8);
        String day = inputDate.substring(8, 10);
        String hour = inputDate.substring(10, 12);
        String minute = inputDate.substring(12, 14);
        String second = inputDate.substring(14, 16);

        return year + "-" + month + "-" + day + " " + hour + ":" + minute + ":" + second;
    }

    private String getDocumentSize(CPDFDocument document) {
        final long MB = 1024 * 1024;
        final int KB = 1024;

        long fileSize = 0L;
        try {
            ParcelFileDescriptor p = document.getContext().getContentResolver().openFileDescriptor(document.getUri(), "r");
            fileSize = p.getStatSize();
            p.close();
        } catch (Exception e) {
            e.printStackTrace();
        }

        float size;
        String unit = " M";
        if (fileSize > MB) {
            size = ((float) fileSize / (1024 * 1024));
        } else if (fileSize > KB) {
            size = ((float) fileSize / 1024);
            unit = " KB";
        } else {
            size = fileSize;
            unit = " B";
        }
        return String.format("%.2f", size) + unit;
    }
}
