/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.pdfmore;

import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.FragmentManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.compdfkit.tools.R;
import com.compdfkit.tools.pdfdisplaysettings.CPDFDisplaySettingDialogFragment;
import com.compdfkit.tools.pdfmore.adapter.CPDFMoreMenuListAdapter;
import com.compdfkit.tools.pdfmore.bean.CMoreMenuBean;
import com.compdfkit.tools.pdfinfo.CPDFDocumentInfoDialogFragment;
import com.compdfkit.tools.pdfview.CPDFView;
import com.compdfkit.tools.utils.dialog.DialogFragmentUtil;
import com.compdfkit.tools.utils.view.CToolBar;
import com.google.android.material.bottomsheet.BottomSheetBehavior;
import com.google.android.material.bottomsheet.BottomSheetDialogFragment;

import java.util.Arrays;


public class CPDFMoreSettingsDialogFragment extends BottomSheetDialogFragment {

    private CToolBar toolBar;

    private RecyclerView rvMoreSettings;

    private CPDFView cpdfView;

    private final CMoreMenuBean[] menus = new CMoreMenuBean[]{
      new CMoreMenuBean(CMoreMenuBean.MENU_DOCUMENT_INFO, R.string.tools_document_info) ,
      new CMoreMenuBean(CMoreMenuBean.MENU_READER_SETTINGS, R.string.tools_reader_settings)
    };

    public static void show(FragmentManager fragmentManager, CPDFView cPdfView){
        CPDFMoreSettingsDialogFragment settingsDialogFragment = new CPDFMoreSettingsDialogFragment();
        settingsDialogFragment.setCPdfReaderView(cPdfView);
        settingsDialogFragment.show(fragmentManager, "moreSettingDialogFragment");
    }

    public void setCPdfReaderView(CPDFView cpdfView) {
        this.cpdfView = cpdfView;
    }

    @Override
    public void onStart() {
        super.onStart();
        BottomSheetBehavior<View> behavior = BottomSheetBehavior.from((View) getView().getParent());
        DialogFragmentUtil.setBottomSheetDialogFragmentFullScreen(getDialog(), behavior);
    }

    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.tools_pdf_more_settings_dialog_fragment,container, false);
        toolBar = rootView.findViewById(R.id.tool_bar);
        toolBar.setBackBtnClickListener(v -> dismiss());
        rvMoreSettings = rootView.findViewById(R.id.rv_more_settings);
        return rootView;
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);

        CPDFMoreMenuListAdapter adapter = new CPDFMoreMenuListAdapter(Arrays.asList(menus));
        adapter.setMenuClickListener(menuType -> {
            switch (menuType){
                case CMoreMenuBean.MENU_DOCUMENT_INFO:
                    CPDFDocumentInfoDialogFragment.show(getParentFragmentManager(), cpdfView);
                    break;
                case CMoreMenuBean.MENU_READER_SETTINGS:
                    CPDFDisplaySettingDialogFragment.show(getParentFragmentManager(), cpdfView);
                    break;
                default:break;
            }
        });
        rvMoreSettings.setLayoutManager(new LinearLayoutManager(getContext()));
        rvMoreSettings.setAdapter(adapter);

    }
}
