/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.pdfmore.adapter;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.appcompat.widget.AppCompatTextView;
import androidx.recyclerview.widget.RecyclerView;

import com.compdfkit.tools.R;
import com.compdfkit.tools.pdfmore.bean.CMoreMenuBean;

import java.util.List;


public class CPDFMoreMenuListAdapter extends RecyclerView.Adapter<CPDFMoreMenuListAdapter.CPDFMoreMenuItemViewHolder> {

    private List<CMoreMenuBean> list;

    private OnMenuClickListener menuClickListener;

    public CPDFMoreMenuListAdapter(List<CMoreMenuBean> list){
        this.list = list;
    }

    @NonNull
    @Override
    public CPDFMoreMenuItemViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        return new CPDFMoreMenuItemViewHolder(LayoutInflater.from(parent.getContext()).inflate(R.layout.tools_more_settings_list_item, parent, false));
    }

    @Override
    public void onBindViewHolder(@NonNull CPDFMoreMenuItemViewHolder holder, int position) {
        CMoreMenuBean item = list.get(holder.getAdapterPosition());
        holder.tvMenuTitle.setText(item.getTitleResId());
        holder.itemView.setOnClickListener(v -> {
            if (menuClickListener != null) {
                menuClickListener.menu(item.getMenuType());
            }
        });
    }

    @Override
    public int getItemCount() {
        return list == null ? 0 : list.size();
    }

    static class CPDFMoreMenuItemViewHolder extends RecyclerView.ViewHolder{

        private AppCompatTextView tvMenuTitle;
        public CPDFMoreMenuItemViewHolder(@NonNull View itemView) {
            super(itemView);
            tvMenuTitle = itemView.findViewById(R.id.tv_more_settings_item_title);
        }
    }


    public void setMenuClickListener(OnMenuClickListener menuClickListener) {
        this.menuClickListener = menuClickListener;
    }

    public interface OnMenuClickListener{
        void menu(int menuType);
    }
}
