package com.compdfkit.tools.pdfsearch;

import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.compdfkit.tools.R;
import com.compdfkit.tools.pdfsearch.adapter.CSearchPDFTextRecyclerviewAdapter;
import com.compdfkit.tools.pdfsearch.bean.CSearchTextInfo;
import com.compdfkit.tools.utils.dialog.DialogFragmentUtil;
import com.compdfkit.tools.utils.view.CToolBar;
import com.google.android.material.bottomsheet.BottomSheetBehavior;
import com.google.android.material.bottomsheet.BottomSheetDialogFragment;

import java.util.List;

public class CSearchResultBottomSheetDialogFragment extends BottomSheetDialogFragment {
    private View mContentView;

    private CToolBar toolBar;
    private RecyclerView recyclerView;

    private List<CSearchTextInfo> searchTextInfos = null;
    private CSearchPDFTextRecyclerviewAdapter searchTextAdapter;
    private CSearchPDFTextRecyclerviewAdapter.OnClickSearchItemListener onClickSearchItemListener;

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public void onStart() {
        super.onStart();
        BottomSheetBehavior<View> behavior = BottomSheetBehavior.from((View) getView().getParent());
        DialogFragmentUtil.setBottomSheetDialogFragmentFullScreen(getDialog(), behavior);
    }

    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        return inflater.inflate(R.layout.tools_search_result, container, false);
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        mContentView = view;
        initView();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
    }

    private void initView() {

        toolBar = mContentView.findViewById(R.id.id_search_head);
        recyclerView = mContentView.findViewById(R.id.id_reader_search_recyclerView);
        LinearLayoutManager layoutManager = new LinearLayoutManager(recyclerView.getContext());
        recyclerView.setLayoutManager(layoutManager);
        searchTextAdapter = new CSearchPDFTextRecyclerviewAdapter();
        recyclerView.setAdapter(searchTextAdapter);
        if (null != searchTextInfos) {
            searchTextAdapter.clearList();
            searchTextAdapter.addList(searchTextInfos);
            searchTextAdapter.notifyDataSetChanged();
        }
        toolBar.setBackBtnClickListener(view -> {
            dismiss();
        });
        searchTextAdapter.setOnClickSearchItemListener(onClickSearchItemListener);
    }

    public void setSearchTextInfos(List<CSearchTextInfo> searchTextInfos) {
        this.searchTextInfos = searchTextInfos;
        if (null != searchTextAdapter) {
            searchTextAdapter.clearList();
            searchTextAdapter.addList(searchTextInfos);
            searchTextAdapter.notifyDataSetChanged();
        }
    }

    public void setOnClickSearchItemListener(CSearchPDFTextRecyclerviewAdapter.OnClickSearchItemListener listener) {
        onClickSearchItemListener = listener;
        if (null != searchTextAdapter) {
            searchTextAdapter.setOnClickSearchItemListener(listener);
        }
    }
}
