package com.compdfkit.tools.pdfsearch;

import android.content.Context;
import android.os.AsyncTask;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.util.AttributeSet;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import androidx.fragment.app.FragmentManager;

import com.compdfkit.tools.R;
import com.compdfkit.tools.pdfsearch.bean.CSearchTextInfo;
import com.compdfkit.tools.pdfsearch.data.CPDFSearchKeywordsDatas;
import com.compdfkit.tools.pdfview.CPDFView;
import com.compdfkit.tools.utils.viewutils.ViewUtils;

import java.util.List;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

public class CSearchToolbar extends RelativeLayout implements View.OnClickListener {
    private TextView completeBt;
    private EditText searchEdit;
    private ImageView leftImage;
    private ImageView rightImage;
    private ImageView listImage;

    private CPDFView cpdfView;

    OnExitSearchListener onExitSearchListener = null;
    List<CSearchTextInfo> searchTextInfos = null;

    private FragmentManager fragmentManager;

    public CSearchToolbar(Context context, AttributeSet attrs) {
        super(context, attrs);
        init(context);

    }

    public CSearchToolbar(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        init(context);
    }


    public void setCpdfView(CPDFView cpdfView) {
        this.cpdfView = cpdfView;
    }

    private void init(Context context) {
        inflate(context, R.layout.tools_search_toolbar, this);
        ViewUtils.applyViewBackground(this);
        completeBt = findViewById(R.id.complete);
        searchEdit = findViewById(R.id.search_word);
        leftImage = findViewById(R.id.iv_search_next);
        rightImage = findViewById(R.id.iv_search_previous);
        listImage = findViewById(R.id.iv_search_list);
        completeBt.setOnClickListener(this);
        leftImage.setOnClickListener(this);
        rightImage.setOnClickListener(this);
        listImage.setOnClickListener(this);

        searchEdit.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {

            }

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count) {

            }

            @Override
            public void afterTextChanged(Editable s) {
                startSearch(searchEdit.getText().toString(), list -> {
                    searchTextInfos = list;
                    if (list.size() > 0) {
                        CSearchTextInfo searchTextInfo = searchTextInfos.get(0);
                        cpdfView.getCPdfReaderView().getTextSearcher().searchBegin(searchTextInfo.page, searchTextInfo.textRangeIndex);
                    }
                });
            }
        });

    }

    Lock lock = new ReentrantLock();
    private AsyncTask<Void, Void, List<CSearchTextInfo>> searchTask;

    private void cancelTask() {
        try {
            lock.lock();
            if (searchTextInfos != null) {
                searchTextInfos.clear();
            }
            if (searchTask != null && !searchTask.isCancelled()) {
                searchTask.cancel(true);
            }
        } finally {
            lock.unlock();
        }
    }

    private void startSearch(String keywords, OnSearchResultListener searchResultListener) {
        if (TextUtils.isEmpty(keywords)) {
            return;
        }
        cancelTask();
        searchTask = new AsyncTask<Void, Void, List<CSearchTextInfo>>() {
            @Override
            protected void onPreExecute() {
                super.onPreExecute();
            }

            @Override
            protected List<CSearchTextInfo> doInBackground(Void... voids) {
                return CPDFSearchKeywordsDatas.startSearch(cpdfView, keywords);
            }

            @Override
            protected void onPostExecute(List<CSearchTextInfo> list) {
                super.onPostExecute(list);
                if (searchResultListener != null) {
                    searchResultListener.result(list);
                }
            }
        };
        searchTask.execute();
    }

    private void previous(){
        cpdfView.getCPdfReaderView().getTextSearcher().searchBackward();
    }

    private void next(){
            cpdfView.getCPdfReaderView().getTextSearcher().searchForward();
    }



    @Override
    public void onClick(View view) {
        int id = view.getId();
        if (id == R.id.complete) {
            cancelTask();
            if (null != onExitSearchListener) {
                onExitSearchListener.exitSearch();
            }
            searchEdit.setText("");
        } else if (id == R.id.iv_search_next) {
            next();
        } else if (id == R.id.iv_search_previous) {
            previous();
        } else if (id == R.id.iv_search_list) {
            startSearch(searchEdit.getText().toString(), list -> {
                if (fragmentManager != null) {
                    CSearchResultBottomSheetDialogFragment searchResultDialog = new CSearchResultBottomSheetDialogFragment();
                    searchResultDialog.show(fragmentManager, "search");
                    searchResultDialog.setSearchTextInfos(list);
                    searchResultDialog.setOnClickSearchItemListener(clickItem -> {
                        cpdfView.getCPdfReaderView().setDisplayPageIndex(clickItem.page);
                        cpdfView.getCPdfReaderView().getTextSearcher().searchBegin(clickItem.page, clickItem.textRangeIndex);
                        searchResultDialog.dismiss();
                    });
                }
            });
        }
    }

    public void setExitSearchListener(OnExitSearchListener onExitSearchListener) {
        this.onExitSearchListener = onExitSearchListener;
    }

    public void bindingFragmentManager(FragmentManager fragmentManager){
        this.fragmentManager = fragmentManager;
    }

    interface OnSearchResultListener {
        void result(List<CSearchTextInfo> list);
    }

    public interface OnExitSearchListener {
        void exitSearch();
    }





}
