/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.pdfview.dialog;

import android.content.Context;
import android.text.TextUtils;
import android.view.Display;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

import androidx.appcompat.app.AppCompatDialog;

import com.compdfkit.tools.R;


public class CCommonInputDialog extends AppCompatDialog {

    private String title;
    private String hintMessageText;
    private String cancelText;
    private String confirmText;
    private OnCancelClickListener cancelClickListener;
    private OnInputCompleteListener onInputCompleteListener;

    private TextView tvTitle;

    private TextView tvMessage;
    private String messageStrTv;

    private EditText etMessage;
    private Button btnCancel;
    private Button btnConfirm;

    public CCommonInputDialog(Context context) {
        super(context);
        initView(context);
    }

    public CCommonInputDialog(Context context, int theme) {
        super(context, theme);
        initView(context);
    }

    protected CCommonInputDialog(Context context, boolean cancelable, OnCancelListener cancelListener) {
        super(context, cancelable, cancelListener);
        initView(context);
    }

    private void initView(Context context) {

        View rootView = View.inflate(context, R.layout.tools_common_input_dialog_layout, null);

        tvTitle = rootView.findViewById(R.id.common_input_dialog_title);

        tvMessage = rootView.findViewById(R.id.common_input_dialog_message);

        etMessage = rootView.findViewById(R.id.common_input_dialog_et);
        btnCancel = rootView.findViewById(R.id.common_input_dialog_cancel);
        btnConfirm = rootView.findViewById(R.id.common_input_dialog_ok);
        btnCancel.setOnClickListener(v -> {
            if (cancelClickListener != null) {
                cancelClickListener.click();
            }
        });

        btnConfirm.setOnClickListener(v -> {
            if (onInputCompleteListener != null) {
                onInputCompleteListener.getInputText(etMessage.getText().toString());
            }
        });

        setContentView(rootView);

        Window window = getWindow();
        WindowManager m = window.getWindowManager();
        Display display = m.getDefaultDisplay();
        WindowManager.LayoutParams p = window.getAttributes();
        p.width = (int) (display.getWidth() * 0.85);
        window.setAttributes(p);
    }

    private void initVisibility() {
        if (TextUtils.isEmpty(title)) {
            tvTitle.setVisibility(View.GONE);
        } else {
            tvTitle.setVisibility(View.VISIBLE);
        }

        if (TextUtils.isEmpty(messageStrTv)) {
            tvMessage.setVisibility(View.GONE);
        } else {
            tvMessage.setVisibility(View.VISIBLE);
        }

        if (cancelClickListener != null) {
            btnCancel.setVisibility(View.VISIBLE);
        } else {
            btnCancel.setVisibility(View.GONE);
        }
    }

    public void setInputType(int type) {
        etMessage.setInputType(type);
    }

    public CCommonInputDialog setTitle(String titleText) {
        this.title = titleText;
        tvTitle.setText(titleText);
        return this;
    }

    public CCommonInputDialog setMessage(String message) {
        this.messageStrTv = message;
        tvMessage.setText(message);
        return this;
    }

    public CCommonInputDialog setHintInputText(String hintMessageText) {
        this.hintMessageText = hintMessageText;
        etMessage.setHint(hintMessageText);
        return this;
    }

    public CCommonInputDialog setCancelCallback(String cancelText, OnCancelClickListener cancelClickListener) {
        this.cancelText = cancelText;
        this.cancelClickListener = cancelClickListener;
        return this;
    }

    public CCommonInputDialog setConfirmCallback(String confirmText, OnInputCompleteListener onInputCompleteListener) {
        this.confirmText = confirmText;
        this.onInputCompleteListener = onInputCompleteListener;
        return this;
    }

    @Override
    public void show() {
        initVisibility();
        super.show();
    }

    public interface OnInputCompleteListener {
        void getInputText(String text);
    }

    public interface OnCancelClickListener {
        void click();
    }
}
