/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.pdfview.dialog;

import android.content.Context;
import android.text.InputType;
import android.text.TextUtils;

import com.compdfkit.tools.R;
import com.compdfkit.tools.interfaces.OnSetPDFDisplayPageIndexListener;

public class CGotoPageDialog extends CCommonInputDialog {

    private OnSetPDFDisplayPageIndexListener onSetPDFDisplayPageIndexListener;

    public CGotoPageDialog(Context context) {
        super(context);
        initDialogView();
    }

    public CGotoPageDialog(Context context, int theme) {
        super(context, theme);
        initDialogView();
    }

    protected CGotoPageDialog(Context context, boolean cancelable, OnCancelListener cancelListener) {
        super(context, cancelable, cancelListener);
        initDialogView();
    }

    public void setOnSetPDFDisplayPageIndexListener(OnSetPDFDisplayPageIndexListener onSetPDFDisplayPageIndexListener) {
        this.onSetPDFDisplayPageIndexListener = onSetPDFDisplayPageIndexListener;
    }


    private void initDialogView() {
        setTitle(R.string.tools_goto_page_dialog_title);
        setMessage(getContext().getResources().getText(R.string.tools_goto_page_dialog_msg).toString());
        setInputType(InputType.TYPE_CLASS_NUMBER);
        setConfirmCallback(getContext().getResources().getText(R.string.tools_common_okay).toString(), text -> {
            if (null != onSetPDFDisplayPageIndexListener && (!TextUtils.isEmpty(text))) {
               int page;
               try {
                   page = Integer.parseInt(text);
                   if (page >= 0) {
                       onSetPDFDisplayPageIndexListener.displayPage(page);
                   }
               } catch (NumberFormatException e) {

               }

            }
            dismiss();
        });
        setCancelCallback(getContext().getResources().getText(R.string.tools_common_cancel).toString(), ()-> dismiss());
    }

}
