/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.pdfview.view;

import android.content.Context;
import android.graphics.Bitmap;
import android.util.AttributeSet;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.request.target.SimpleTarget;
import com.bumptech.glide.request.transition.Transition;
import com.compdfkit.tools.R;
import com.compdfkit.tools.pdfview.CPDFView;
import com.compdfkit.tools.utils.glide.pdf.CPDFWrapper;
import com.compdfkit.ui.widget.CPDFSlideBar;


/**
 *
 *
 *
 *
 */
public class CPDFSliderBarView extends CPDFSlideBar implements CPDFSlideBar.OnScrollToPageListener {

    int currentScrollPageIndex = -1;

    private int sliderBarThumbnailWidth = 314;
    private int sliderBarThumbnailHeight = 444;

    private CPDFView cpdfView;

    public CPDFSliderBarView(Context context) {
        this(context, null);
    }

    public CPDFSliderBarView(Context context, @Nullable AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public CPDFSliderBarView(Context context, @Nullable AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        setOnScrollToPageListener(this);
    }


    public void bindCPdfReaderView(CPDFView cpdfView) {
        this.cpdfView = cpdfView;
        if (cpdfView.getCPdfReaderView().getPDFDocument() != null) {
            setPageCount(cpdfView.getCPdfReaderView().getPDFDocument().getPageCount());
        }
    }

    public void initSliderBar(CPDFSlideBar.SlideBarPosition position, int thumbnailWidth, int thumbnailHeight) {
        sliderBarThumbnailWidth = thumbnailWidth;
        sliderBarThumbnailHeight = thumbnailHeight;
        setDefaultThumbnailSize(sliderBarThumbnailWidth, sliderBarThumbnailHeight);
        setSlideBarBitmap(R.drawable.tools_ic_pdf_slider_bar);
        setSlideBarPosition(position);
    }


    @Override
    public void onScrollBegin(int pageIndex) {
        if (cpdfView != null) {
            cpdfView.getCPdfReaderView().removeAllAnnotFocus();
        }
    }

    @Override
    public void onScroll(int pageIndex) {

    }

    @Override
    public void onScrollEnd(int pageIndex) {
        currentScrollPageIndex = -1;
        cpdfView.getCPdfReaderView().setDisplayPageIndex(pageIndex);
    }

    @Override
    public void onScrollToPage(int pageIndex) {
        refreshDocumentPageThumbnail(pageIndex);
    }


    private void refreshDocumentPageThumbnail(int pageIndex) {
        if (currentScrollPageIndex != pageIndex) {
            currentScrollPageIndex = pageIndex;
            Glide.with(getContext())
                    .asBitmap()
                    .load(CPDFWrapper.fromDocument(cpdfView.getCPdfReaderView().getPDFDocument(), currentScrollPageIndex))
                    .diskCacheStrategy(DiskCacheStrategy.NONE)
                    .into(new SimpleTarget<Bitmap>(sliderBarThumbnailWidth, sliderBarThumbnailHeight) {
                        @Override
                        public void onResourceReady(@NonNull Bitmap resource, @Nullable Transition<? super Bitmap> transition) {
                            setThumbnailBitmap(resource);
                        }
                    });
        }
    }
}
