/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.utils.viewutils;


import android.content.Context;
import android.content.res.ColorStateList;
import android.content.res.TypedArray;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.util.TypedValue;
import android.view.View;

import androidx.appcompat.content.res.AppCompatResources;
import androidx.core.view.ViewCompat;

import com.google.android.material.shape.MaterialShapeDrawable;

public class ViewUtils {

    public static Drawable loadDrawableFromAttributes(Context context, TypedArray typedArray, int index, int defValue) {
        Drawable drawable = null;
        try {
            int resId = typedArray.getResourceId(index, defValue);
            if (resId != -1) {
                drawable = AppCompatResources.getDrawable(context, resId);
            }
            return drawable;
        } catch (Exception e) {
            return null;
        }
    }


    public static void applyViewBackground(View view){
        int color;
        if (view.getBackground() != null && view.getBackground() instanceof ColorDrawable) {
            ColorDrawable colorDrawable = (ColorDrawable) view.getBackground();
            color = colorDrawable.getColor();
        } else {
            TypedValue typedValue = new TypedValue();
            view.getContext().getTheme().resolveAttribute(com.google.android.material.R.attr.colorSurface, typedValue, true);
            color = typedValue.data;
        }
        MaterialShapeDrawable materialShapeDrawable = new MaterialShapeDrawable();
        materialShapeDrawable.setFillColor(ColorStateList.valueOf(color));
        materialShapeDrawable.initializeElevationOverlay(view.getContext());
        materialShapeDrawable.setElevation(ViewCompat.getElevation(view));
        ViewCompat.setBackground(view, materialShapeDrawable);
    }



}
