/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.demo.viewer;

import android.os.Bundle;
import android.view.View;

import androidx.appcompat.app.AppCompatActivity;

import com.compdfkit.demo.viewer.databinding.ViewerActivityMainBinding;
import com.compdfkit.tools.pdfbota.bota.CPDFBotaDialogFragment;
import com.compdfkit.tools.pdfmore.CPDFMoreSettingsDialogFragment;
import com.compdfkit.tools.utils.task.CExtractAssetFileTask;
import com.compdfkit.ui.textsearch.ITextSearcher;

public class MainActivity extends AppCompatActivity {

    /**
     * assets folder pdf file
     */
    public static final String QUICK_START_GUIDE = "Quick Start Guide V2.4.0.pdf";

    private ViewerActivityMainBinding binding;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        binding = ViewerActivityMainBinding.inflate(getLayoutInflater());
        setContentView(binding.getRoot());
        initToolbarListener();
        initSearchBar();
        //Extract PDF files from the Android assets folder
        CExtractAssetFileTask.extract(this, QUICK_START_GUIDE, QUICK_START_GUIDE, (pdfFile) ->
                runOnUiThread(() -> {
                    binding.pdfView.openPdfFile(pdfFile.getAbsolutePath());
                }));

    }


    private void initToolbarListener(){
        binding.pdfToolBar.setSearchBtnClickListener(v -> {
            binding.pdfToolBar.setVisibility(View.GONE);
            binding.pdfSearchToolBar.setVisibility(View.VISIBLE);
        });
        binding.pdfToolBar.setBoTaBtnClickListener(v -> {
            //Show a fragment of the PDF thumbnail and a dialog fragment of the PDF outline list.
            CPDFBotaDialogFragment botaDialogFragment = CPDFBotaDialogFragment.newInstance();
            botaDialogFragment.setCPdfReaderView(binding.pdfView);
            botaDialogFragment.show(getSupportFragmentManager(), "boTaDialogFragment");
        });
        binding.pdfToolBar.setMoreBtnClickListener(v -> {
            //Show the PDF settings dialog fragment
            CPDFMoreSettingsDialogFragment.show(getSupportFragmentManager(), binding.pdfView);
        });
    }

    private void initSearchBar() {

        binding.pdfSearchToolBar.setCpdfView(binding.pdfView);
        binding.pdfSearchToolBar.bindingFragmentManager(getSupportFragmentManager());
        binding.pdfSearchToolBar.setExitSearchListener(()->{
            ITextSearcher searcher = binding.pdfView.getCPdfReaderView().getTextSearcher();
            if (searcher != null) {
                searcher.cancelSearch();
                binding.pdfView.getCPdfReaderView().invalidateAllChildren();
            }
            binding.pdfToolBar.setVisibility(View.VISIBLE);
            binding.pdfSearchToolBar.setVisibility(View.GONE);
        });
    }

}